@@ -778,7 +778,7 @@ function *(a::T, b::PolyRingElem{T}) where {T <: RingElem}
    return z
 end
 
-function *(a::Union{Integer, Rational, AbstractFloat}, b::PolynomialElem)
+function *(a::JuliaRingElement, b::PolynomialElem)
    len = length(b)
    z = parent(b)()
    fit!(z, len)
@@ -791,7 +791,7 @@ end
 
 *(a::PolyRingElem{T}, b::T) where {T <: RingElem} = b*a
 
-*(a::PolynomialElem, b::Union{Integer, Rational, AbstractFloat}) = b*a
+*(a::PolynomialElem, b::JuliaRingElement) = b*a
 
 ###############################################################################
 #
@@ -936,35 +936,15 @@ end
 #
 ###############################################################################
 
-@doc raw"""
-    ==(x::PolyRingElem{T}, y::T) where {T <: RingElem}
-
-Return `true` if $x == y$.
-"""
 ==(x::PolyRingElem{T}, y::T) where T <: RingElem = ((length(x) == 0 && iszero(y))
                         || (length(x) == 1 && coeff(x, 0) == y))
 
-@doc raw"""
-    ==(x::PolynomialElem, y::Union{Integer, Rational, AbstractFloat})
-
-Return `true` if $x == y$ arithmetically, otherwise return `false`.
-"""
-==(x::PolynomialElem, y::Union{Integer, Rational, AbstractFloat}) = ((length(x) == 0 && iszero(base_ring(x)(y)))
+==(x::PolynomialElem, y::JuliaRingElement) = ((length(x) == 0 && iszero(base_ring(x)(y)))
                         || (length(x) == 1 && coeff(x, 0) == y))
 
-@doc raw"""
-    ==(x::T, y::PolyRingElem{T}) where T <: RingElem = y == x
-
-Return `true` if $x = y$.
-"""
 ==(x::T, y::PolyRingElem{T}) where T <: RingElem = y == x
 
-@doc raw"""
-    ==(x::Union{Integer, Rational, AbstractFloat}, y::PolyRingElem)
-
-Return `true` if $x == y$ arithmetically, otherwise return `false`.
-"""
-==(x::Union{Integer, Rational, AbstractFloat}, y::PolyRingElem) = y == x
+==(x::JuliaRingElement, y::PolyRingElem) = y == x
 
 ###############################################################################
 #
@@ -1486,7 +1466,7 @@ function divexact(a::PolyRingElem{T}, b::T; check::Bool=true) where {T <: RingEl
    return z
 end
 
-function divexact(a::PolyRingElem, b::Union{Integer, Rational, AbstractFloat}; check::Bool=true)
+function divexact(a::PolyRingElem, b::JuliaRingElement; check::Bool=true)
    iszero(b) && throw(DivideError())
    z = parent(a)()
    fit!(z, length(a))
@@ -1825,23 +1805,12 @@ function sqrt_classical(f::PolyRingElem{T}; check::Bool=true) where T <: RingEle
    return true, q
 end
 
-@doc raw"""
-    Base.sqrt(f::PolyRingElem{T}; check::Bool=true) where T <: RingElement
-
-Return the square root of $f$. By default the function checks the input is
-square and raises an exception if not. If `check=false` this check is omitted.
-"""
 function Base.sqrt(f::PolyRingElem{T}; check::Bool=true) where T <: RingElement
    flag, q = sqrt_classical(f; check=check)
    check && !flag && error("Not a square in sqrt")
    return q
 end
 
-@doc raw"""
-    is_square(f::PolyRingElem{T}) where T <: RingElement
-
-Return `true` if $f$ is a perfect square.
-"""
 function is_square(f::PolyRingElem{T}) where T <: RingElement
    flag, q = sqrt_classical(f)
    return flag
