@@ -47,8 +47,8 @@ divexact_right(x::T, y::T; check::Bool=true) where T <: RingElement = divexact(x
 
 Base.:/(x::ModuleElem, y::RingElement) = divexact(x, y; check=true)
 Base.:/(x::RingElem, y::RingElem) = divexact(x, y; check=true)
-Base.:/(x::RingElem, y::Union{Integer, Rational, AbstractFloat}) = divexact(x, y; check=true)
-Base.:/(x::Union{Integer, Rational, AbstractFloat}, y::RingElem) = divexact(x, y; check=true)
+Base.:/(x::RingElem, y::JuliaRingElement) = divexact(x, y; check=true)
+Base.:/(x::JuliaRingElement, y::RingElem) = divexact(x, y; check=true)
 
 Base.inv(x::RingElem) = divexact(one(parent(x)), x)
 
@@ -160,13 +160,6 @@ end
 #
 ################################################################################
 
-@doc raw"""
-    sqrt(a::FieldElem)
-
-Return the square root of the element `a`. By default the function will
-throw an exception if the input is not square. If `check=false` this test is
-omitted.
-"""
 function Base.sqrt(a::FieldElem; check::Bool=true)
   R = parent(a)
   R, t = polynomial_ring(R, :t; cached = false)
