@@ -40,12 +40,6 @@ number_of_generators(S::UniversalPolyRing) = number_of_generators(mpoly_ring(S))
 
 symbols(S::UniversalPolyRing) = symbols(mpoly_ring(S))
 
-function vars(p::UnivPoly{T}) where {T}
-   S = parent(p)
-   V = vars(data(p))
-   return [UnivPoly{T}(v, S) for v in V]
-end
-
 internal_ordering(p::UniversalPolyRing) = internal_ordering(mpoly_ring(p))
 
 data(p::UnivPoly{T}) where {T<:RingElement} = p.p::mpoly_type(T)
@@ -68,11 +62,9 @@ end
 function set_exponent_vector!(p::UnivPoly, i::Int, exps::Vector{Int})
    S = parent(p)
    len = length(exps)
-   if len != nvars(parent(data(p)))
-      p.p = upgrade(S, data(p))
-      if len < nvars(S)
-         exps = vcat(exps, zeros(Int, nvars(S) - len))
-      end
+   upgrade!(p)
+   if len < nvars(S)
+      exps = vcat(exps, zeros(Int, nvars(S) - len))
    end
    p.p = set_exponent_vector!(data(p), i, exps)
    return p
@@ -99,11 +91,9 @@ function setcoeff!(p::UnivPoly, exps::Vector{Int}, c::T) where T <: RingElement
    c = base_ring(data(p))(c)
    S = parent(p)
    len = length(exps)
-   if len != nvars(parent(data(p)))
-      p.p = upgrade(S, data(p))
-      if len < nvars(S)
-         exps = vcat(exps, zeros(Int, nvars(S) - len))
-      end
+   upgrade!(p)
+   if len < nvars(S)
+      exps = vcat(exps, zeros(Int, nvars(S) - len))
    end
    p.p = setcoeff!(data(p), exps, c)
    return p
@@ -286,6 +276,8 @@ end
 
 var_index(x::UnivPoly) = var_index(data(x))
 
+var_indices(p::UnivPoly) = var_indices(data(p))
+
 function vars(p::UnivPoly{T}) where {T <: RingElement}
    V = vars(data(p))
    S = parent(p)
@@ -526,7 +518,7 @@ end
 
 for op in (:+, :-, :*)
   @eval begin
-    function $op(p::UnivPoly{T}, n::Union{Integer, Rational, AbstractFloat}) where {T}
+    function $op(p::UnivPoly{T}, n::JuliaRingElement) where {T}
        S = parent(p)
        return UnivPoly{T}($op(data(p),n), S)
     end
@@ -536,7 +528,7 @@ for op in (:+, :-, :*)
        return UnivPoly{T}($op(data(p),n), S)
     end
 
-    function $op(n::Union{Integer, Rational, AbstractFloat}, p::UnivPoly{T}) where {T}
+    function $op(n::JuliaRingElement, p::UnivPoly{T}) where {T}
        S = parent(p)
        return UnivPoly{T}($op(n,data(p)), S)
     end
@@ -548,7 +540,7 @@ for op in (:+, :-, :*)
   end
 end
 
-function divexact(p::UnivPoly{T}, n::Union{Integer, Rational, AbstractFloat}; check::Bool=true) where {T}
+function divexact(p::UnivPoly{T}, n::JuliaRingElement; check::Bool=true) where {T}
    S = parent(p)
    return UnivPoly{T}(divexact(data(p), n; check=check), S)
 end
@@ -615,20 +607,7 @@ end
 
 function isless(a::UnivPoly{T}, b::UnivPoly{T}) where {T}
    check_parent(a, b)
-   if parent(data(a)) === parent(data(b))
-      return isless(data(a), data(b))
-   end
-   S = parent(a)
-   num = nvars(S)
-   s = data(a)
-   t = data(b)
-   if nvars(parent(s)) != num
-      s = upgrade(S, s)
-   end
-   if nvars(parent(t)) != num
-      t = upgrade(S, t)
-   end
-   return isless(s, t)
+   return isless(data(upgrade!(a)), data(upgrade!(b)))
 end
 
 ###############################################################################
@@ -637,9 +616,9 @@ end
 #
 ###############################################################################
 
-==(p::UnivPoly, n::Union{Integer, Rational, AbstractFloat}) = data(p) == n
+==(p::UnivPoly, n::JuliaRingElement) = data(p) == n
 
-==(n::Union{Integer, Rational, AbstractFloat}, p::UnivPoly) = data(p) == n
+==(n::JuliaRingElement, p::UnivPoly) = data(p) == n
 
 ==(p::UnivPoly{T}, n::T) where {T <: RingElem} = data(p) == n
 
@@ -666,22 +645,15 @@ deflation(p::UnivPoly{T}) where {T} = deflation(data(p))
 
 function deflate(p::UnivPoly{T}, shift::Vector{Int}, defl::Vector{Int}) where {T}
    S = parent(p)
+   num = nvars(S)
    vlen = length(shift)
    vlen != length(defl) && error("Vector lengths do not match")
-   num = nvars(parent(data(p)))
-   pp = data(p)
-   if vlen == num
-      return UnivPoly{T}(deflate(pp, shift, defl), S)
-   end
-   if vlen > num
-      pp = upgrade(S, pp)
-      num = nvars(parent(pp))
-   end
+   upgrade!(p)
    if vlen < num
       shift = vcat(shift, zeros(Int, num - vlen))
       defl = vcat(defl, ones(Int, num - vlen))
    end
-   return UnivPoly{T}(deflate(pp, shift, defl), S)
+   return UnivPoly{T}(deflate(data(p), shift, defl), S)
 end
 
 function deflate(p::UnivPoly{T}, defl::Vector{Int}) where {T}
@@ -690,22 +662,15 @@ end
 
 function inflate(p::UnivPoly{T}, shift::Vector{Int}, defl::Vector{Int}) where {T}
    S = parent(p)
+   num = nvars(S)
    vlen = length(shift)
    vlen != length(defl) && error("Vector lengths do not match")
-   num = nvars(parent(data(p)))
-   pp = data(p)
-   if vlen == num
-      return UnivPoly{T}(inflate(pp, shift, defl), S)
-   end
-   if vlen > num
-      pp = upgrade(S, pp)
-      num = nvars(parent(pp))
-   end
+   upgrade!(p)
    if vlen < num
       shift = vcat(shift, zeros(Int, num - vlen))
       defl = vcat(defl, ones(Int, num - vlen))
    end
-   return UnivPoly{T}(inflate(pp, shift, defl), S)
+   return UnivPoly{T}(inflate(data(p), shift, defl), S)
 end
 
 function inflate(p::UnivPoly{T}, defl::Vector{Int}) where {T}
@@ -804,7 +769,7 @@ function evaluate(a::UnivPoly{T}, A::Vector{T}) where {T <: RingElem}
    return evaluate(data(a), A)
 end
 
-function evaluate(a::UnivPoly{T}, A::Vector{V}) where {T <: RingElement, V <: Union{Integer, Rational, AbstractFloat}}
+function evaluate(a::UnivPoly{T}, A::Vector{V}) where {T <: RingElement, V <: JuliaRingElement}
    n = length(A)
    num = nvars(parent(data(a)))
    if n > num
@@ -851,11 +816,11 @@ function (a::UnivPoly{T})(vals::T...) where {T <: RingElement}
    return evaluate(a, [vals...])
 end
 
-function (a::UnivPoly{T})(val::V, vals::V...) where {T <: RingElement, V <: Union{Integer, Rational, AbstractFloat}}
+function (a::UnivPoly{T})(val::V, vals::V...) where {T <: RingElement, V <: JuliaRingElement}
    return evaluate(a, [val, vals...])
 end
 
-function (a::UnivPoly{T})(vals::Union{NCRingElem, RingElement}...) where {T <: RingElement}
+function (a::UnivPoly{T})(vals::NCRingElement...) where {T <: RingElement}
    A = [vals...]
    n = length(vals)
    num = nvars(parent(data(a)))
@@ -1172,12 +1137,21 @@ end
 
 function upgrade(S::UniversalPolyRing{T}, pp::MPolyRingElem{T}) where {T}
    n = nvars(S) - nvars(parent(pp))
-   ctx = MPolyBuildCtx(mpoly_ring(S))
-   v0 = zeros(Int, n)
-   for (c, v) in zip(coefficients(pp), exponent_vectors(pp))
-      push_term!(ctx, c, vcat(v, v0))
+   if n > 0
+      ctx = MPolyBuildCtx(mpoly_ring(S))
+      v0 = zeros(Int, n)
+      for (c, v) in zip(coefficients(pp), exponent_vectors(pp))
+         push_term!(ctx, c, vcat(v, v0))
+      end
+      return finish(ctx)
+   else
+      return pp
    end
-   return finish(ctx)
+end
+
+function upgrade!(p::UnivPoly)
+   p.p = upgrade(parent(p), data(p))
+   return p
 end
 
 function (a::UniversalPolyRing{T})(b::RingElement) where {T <: RingElement}
@@ -1188,7 +1162,7 @@ function (a::UniversalPolyRing{T})() where {T <: RingElement}
    return UnivPoly{T}(mpoly_ring(a)(), a)
 end
 
-function (a::UniversalPolyRing{T})(b::Union{Integer, Rational, AbstractFloat}) where {T <: RingElement}
+function (a::UniversalPolyRing{T})(b::JuliaRingElement) where {T <: RingElement}
    return UnivPoly{T}(mpoly_ring(a)(b), a)
 end
 
@@ -1198,11 +1172,7 @@ end
 
 function (S::UniversalPolyRing{T})(p::UnivPoly{T}) where {T <: RingElement}
    parent(p) !== S && error("Unable to coerce")
-   n = nvars(S) - nvars(parent(data(p)))
-   if n != 0
-      p = UnivPoly{T}(upgrade(S, data(p)), S)
-   end
-   return p
+   return upgrade!(p)
 end
 
 function (a::UniversalPolyRing{T})(b::Vector{T}, m::Vector{Vector{Int}}) where {T <: RingElement}
