@@ -107,6 +107,7 @@ import ..AbstractAlgebra: characteristic
 import ..AbstractAlgebra: check_parent
 import ..AbstractAlgebra: codomain
 import ..AbstractAlgebra: coeff
+import ..AbstractAlgebra: coeff!
 import ..AbstractAlgebra: coefficient_ring
 import ..AbstractAlgebra: coefficient_ring_type
 import ..AbstractAlgebra: coefficients
@@ -130,7 +131,9 @@ import ..AbstractAlgebra: domain
 import ..AbstractAlgebra: elem_type
 import ..AbstractAlgebra: evaluate
 import ..AbstractAlgebra: exp
+import ..AbstractAlgebra: exponent_vector
 import ..AbstractAlgebra: exponent_vectors
+import ..AbstractAlgebra: exponent_vector!
 import ..AbstractAlgebra: expressify
 import ..AbstractAlgebra: factor
 import ..AbstractAlgebra: factor_squarefree
@@ -167,6 +170,7 @@ import ..AbstractAlgebra: is_univariate_with_data
 import ..AbstractAlgebra: is_zero_divisor
 import ..AbstractAlgebra: is_zero_divisor_with_annihilator
 import ..AbstractAlgebra: isreduced_form
+import ..AbstractAlgebra: JuliaRingElement
 import ..AbstractAlgebra: leading_coefficient
 import ..AbstractAlgebra: leading_exponent_vector
 import ..AbstractAlgebra: leading_monomial
@@ -178,6 +182,7 @@ import ..AbstractAlgebra: max_precision
 import ..AbstractAlgebra: minpoly
 import ..AbstractAlgebra: modulus
 import ..AbstractAlgebra: monomials
+import ..AbstractAlgebra: monomial!
 import ..AbstractAlgebra: mul!
 import ..AbstractAlgebra: mul_classical
 import ..AbstractAlgebra: mul_karatsuba
@@ -217,6 +222,7 @@ import ..AbstractAlgebra: symbols
 import ..AbstractAlgebra: tail
 import ..AbstractAlgebra: term_degree
 import ..AbstractAlgebra: terms
+import ..AbstractAlgebra: term!
 import ..AbstractAlgebra: terms_degrees
 import ..AbstractAlgebra: terse
 import ..AbstractAlgebra: to_univariate
@@ -226,6 +232,7 @@ import ..AbstractAlgebra: use_karamul
 import ..AbstractAlgebra: valuation
 import ..AbstractAlgebra: var
 import ..AbstractAlgebra: var_index
+import ..AbstractAlgebra: var_indices
 import ..AbstractAlgebra: vars
 import ..AbstractAlgebra: vector_space_dim
 import ..AbstractAlgebra: zero!
